# This file was auto-generated by Fern from our API Definition.

import typing

from .map_layer import MapLayer
from .weather_layer import WeatherLayer

UnifiedDashboardResponseLayersItem = typing.Union[WeatherLayer, MapLayer]
