# This file was auto-generated by Fern from our API Definition.

import typing

UpdateLayerApiV1DashboardLayersLayerIdPutRequestWeatherLayerType = typing.Union[
    typing.Literal["wl:RasterLayer", "wl:ParticleLayer", "wl:IsolineLayer"], typing.Any
]
